import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split
import tensorflow as tf
from tensorflow import keras
import os
import random

data=np.load('X_train.npy')
labels=np.load('labels_train.npy')

x_train, x_test, y_train, y_test = train_test_split(data, labels, test_size = 0.3, random_state = 101)
x_train = x_train / 255.0
x_test = x_test / 255.0


model = keras.models.Sequential()
model.add(keras.layers.Conv2D(32, kernel_size=(5, 5), activation=tf.nn.relu, input_shape=(96, 96, 1)))
model.add(keras.layers.MaxPooling2D(pool_size=(2,2)))
model.add(keras.layers.Conv2D(64, kernel_size=(5,5), activation=tf.nn.relu))
model.add(keras.layers.MaxPooling2D(pool_size=(2,2)))
model.add(keras.layers.Conv2D(128, kernel_size=(5,5), activation=tf.nn.relu))
model.add(keras.layers.MaxPooling2D(pool_size=(2,2)))
model.add(keras.layers.Dropout(0.1))
model.add(keras.layers.Flatten())
model.add(keras.layers.Dense(128, activation = 'relu'))
model.add(keras.layers.Dropout(0.1))
model.add(keras.layers.BatchNormalization())
model.add(keras.layers.Dense(1, activation = 'sigmoid'))

model.compile(optimizer='adam', 
              loss='binary_crossentropy',
              metrics=['accuracy'])
model.fit(x_train, y_train, epochs=10, batch_size=32)
test_loss, test_acc = model.evaluate(x_test, y_test)
print('Test accuracy:', test_acc)